==> Bencher-Scenarios-MojoDOM-0.001.tar.gz: Bencher-Scenarios-MojoDOM-0.001/lib/Bencher/ScenarioUtil/MojoDOM.pm <==
package Bencher::ScenarioUtil::MojoDOM;

our $DATE = '2016-04-01'; # DATE
our $VERSION = '0.001'; # VERSION

use PERLANCAR::HTML::Tree::Examples qw(gen_sample_html);

our %htmls = (
    small1  => gen_sample_html(size => 'small1'),
    medium1 => gen_sample_html(size => 'medium1'),
);

our @datasets = (
    {name => 'small1' , summary => '16 elements, 4 levels, '.length($htmls{small1}).' bytes' , args=>{size=>'small1' }},
    {name => 'medium1', summary => '20k elements, 7 levels, '.length($htmls{medium1}).' bytes', args=>{size=>'medium1'}},
);

1;
# ABSTRACT: Utility routines

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::ScenarioUtil::MojoDOM - Utility routines

=head1 VERSION

This document describes version 0.001 of Bencher::ScenarioUtil::MojoDOM (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-01.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-MojoDOM>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-MojoDOM>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-MojoDOM>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Bencher-Scenarios-MojoDOM-0.002.tar.gz: Bencher-Scenarios-MojoDOM-0.002/lib/Bencher/ScenarioUtil/MojoDOM.pm <==
package Bencher::ScenarioUtil::MojoDOM;

our $DATE = '2016-04-01'; # DATE
our $VERSION = '0.002'; # VERSION

our @datasets = (
    {name => 'small1' , summary => '16 elements, 4 levels, '.length($htmls{small1}).' bytes' , args=>{size=>'small1' }},
    {name => 'medium1', summary => '20k elements, 7 levels, '.length($htmls{medium1}).' bytes', args=>{size=>'medium1'}},
);

# we want to record the version of these modules too in the benchmark result
# metadata
our @extra_modules = (
    'PERLANCAR::HTML::Tree::Examples',
);

1;
# ABSTRACT: Utility routines

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::ScenarioUtil::MojoDOM - Utility routines

=head1 VERSION

This document describes version 0.002 of Bencher::ScenarioUtil::MojoDOM (from Perl distribution Bencher-Scenarios-MojoDOM), released on 2016-04-01.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-MojoDOM>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-MojoDOM>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-MojoDOM>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
